import org.codehaus.groovy.grails.plugins.ext.Ext

class ExtTagLib {

    static namespace = "ext"
    
    /**
     * Includes a Ext javascript file from the Ext distribution folder
     *  
     * <ext:javascript dir="build/widgets" file="DatePicker-min.js" /> 
     * 
     * Actually imports '/app/js/ext/{version}/build/widgets/DatePicker-min.js'
     * 
     * @param dir (Optional) The name of the directory within the ext folder to link to
     * @param file The name of the file to link to
     **/
    def javascript = { attrs ->
        if (!attrs.file)
            throwTagError("Tag [javascript] is missing required attribute [file]")

        def version = attrs.version ? attrs.remove('version') : Ext.version
        def dir = "js/ext/${version}"
        if (attrs.dir) {
            dir += "/${attrs.dir}"
        }
            
        def src = createLinkTo(dir: "${dir}", file: attrs.file)
        out << "<script type=\"text/javascript\" src=\"${src}\"></script>"
    }
    
    /**
     * Includes a Ext stylesheet file from the Ext distribution folder
     *
     * <ext:stylesheet dir="resources/css" file="date-picker.css" />
     * 
     * Actually imports '/app/js/ext/{version}/resources/css/date-picker.css'
     * 
     * @param dir The name of the directory within the ext folder to link to 
     * @param file The name of the file to link to 
     **/
    def stylesheet = { attrs ->
        if (!attrs.file)
            throwTagError("Tag [stylesheet] is missing required attribute [file]")

        def version = attrs.version ? attrs.remove('version') : Ext.version
        def dir = "js/ext/${version}"
        if (attrs.dir) {
            dir += "/${attrs.dir}"
        }        
                
        def href = createLinkTo(dir: "${dir}", file: attrs.file)
        out << "<link rel=\"stylesheet\" type=\"text/css\" href=\"${href}\" />"
    }
}
