import org.codehaus.groovy.grails.web.util.WebUtils
import org.springframework.web.context.request.RequestContextHolder

class ExtRemoteFunctionTagTests extends grails.test.GroovyPagesTestCase {

    void testExtRemoteFunctionWithUpdate() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" update="success">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){Ext.get('success').dom.innerHTML = response.responseText;}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionWithUpdateMap() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" update="[success: \'success\', failure: \'error\']">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){Ext.get('success').dom.innerHTML = response.responseText;}, failure: function(response, options){Ext.get('error').dom.innerHTML = response.statusText;}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionWithBefore() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" before="before()">My Action</g:remoteFunction>'
        assertOutputEquals "before();Ext.Ajax.request({success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionWithAfter() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" after="after()">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});after();", template
    }
    
    void testExtRemoteFunctionWithOnSuccess() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onSuccess="success()">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){success();}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionWithOnFailure() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onFailure="failure()">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){}, failure: function(response, options){failure();}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionWithOnLoading() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onLoading="loading()">My Action</g:remoteFunction>'
        assertOutputEquals "loading();Ext.Ajax.request({success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionWithOnLoaded() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onLoaded="loaded()">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){loaded();}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionWithOnComplete() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onComplete="complete()">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){complete();}, failure: function(response, options){complete();}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionWithAllOnEvents() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onSuccess="success()" onFailure="failure()" onLoading="loading()" onLoaded="loaded()" onComplete="complete()">My Action</g:remoteFunction>'
        assertOutputEquals "loading();Ext.Ajax.request({success: function(response, options){loaded();success();complete();}, failure: function(response, options){failure();complete();}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionWithAllOnEventsAndUpdate() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onSuccess="success()" onFailure="failure()" onLoading="loading()" onLoaded="loaded()" onComplete="complete()" update="success">My Action</g:remoteFunction>'
        assertOutputEquals "loading();Ext.Ajax.request({success: function(response, options){loaded();Ext.get('success').dom.innerHTML = response.responseText;success();complete();}, failure: function(response, options){failure();complete();}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionWithAllOnEventsAndUpdateMap() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" onSuccess="success()" onFailure="failure()" onLoading="loading()" onLoaded="loaded()" onComplete="complete()" update="[success: \'success\', failure: \'error\']">My Action</g:remoteFunction>'
        assertOutputEquals "loading();Ext.Ajax.request({success: function(response, options){loaded();Ext.get('success').dom.innerHTML = response.responseText;success();complete();}, failure: function(response, options){Ext.get('error').dom.innerHTML = response.statusText;failure();complete();}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionWithClassAttribute() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" class="myclass">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }
    
    void testExtRemoteFunctionGetWithoutParams() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="GET">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({method: 'GET', success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionGetWithSingleParam() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="GET" params="[var1: \'one\']">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({method: 'GET', success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1', params: 'var1=one'});", template
    }
    
    void testExtRemoteFunctionGetWithMultipleParams() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="GET" params="[var1: \'one\', var2: \'two\']">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({method: 'GET', success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1', params: 'var1=one&var2=two'});", template
    }
    
    void testExtRemoteFunctionPostWithoutParams() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="POST">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({method: 'POST', success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1'});", template
    }

    void testExtRemoteFunctionPostWithSingleParam() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="POST" params="[var1: \'one\']">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({method: 'POST', success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1', params: 'var1=one'});", template
    }
    
    void testExtRemoteFunctionPostWithMultipleParams() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="POST" params="[var1: \'one\', var2: \'two\']">My Action</g:remoteFunction>'
        assertOutputEquals "Ext.Ajax.request({method: 'POST', success: function(response, options){}, failure: function(response, options){}, url: '/myapp/mycontroller/myaction/1', params: 'var1=one&var2=two'});", template
    }
    
    void testExtRemoteFunctionGetWithEverything() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="GET" params="[var1: \'one\', var2: \'two\']" before="before()" after="after()" onSuccess="success()" onFailure="failure()" onLoading="loading()" onLoaded="loaded()" onComplete="complete()" update="[success: \'success\', failure: \'error\']">My Action</g:remoteFunction>'
        assertOutputEquals "before();loading();Ext.Ajax.request({method: 'GET', success: function(response, options){loaded();Ext.get('success').dom.innerHTML = response.responseText;success();complete();}, failure: function(response, options){Ext.get('error').dom.innerHTML = response.statusText;failure();complete();}, url: '/myapp/mycontroller/myaction/1', params: 'var1=one&var2=two'});after();", template
    }
    
    void testExtRemoteFunctionPostWithEverything() {
        def template = '<g:remoteFunction controller="mycontroller" action="myaction" id="1" method="POST" params="[var1: \'one\', var2: \'two\']" before="before()" after="after()" onSuccess="success()" onFailure="failure()" onLoading="loading()" onLoaded="loaded()" onComplete="complete()" update="[success: \'success\', failure: \'error\']">My Action</g:remoteFunction>'
        assertOutputEquals "before();loading();Ext.Ajax.request({method: 'POST', success: function(response, options){loaded();Ext.get('success').dom.innerHTML = response.responseText;success();complete();}, failure: function(response, options){Ext.get('error').dom.innerHTML = response.statusText;failure();complete();}, url: '/myapp/mycontroller/myaction/1', params: 'var1=one&var2=two'});after();", template
    }
    
    void setUp() {
        RequestContextHolder.currentRequestAttributes().currentRequest."${WebUtils.INCLUDE_CONTEXT_PATH_ATTRIBUTE}" = '/myapp'
        RequestContextHolder.currentRequestAttributes().currentRequest."org.codehaus.grails.INCLUDED_JS_LIBRARIES" = ['ext']
    }
}
