package org.codehaus.groovy.grails.plugins.web.taglib;

/**
 * An implementation for the Ext JavaScript Library.
 */
class ExtProvider implements JavascriptProvider {

    def doRemoteFunction(taglib, attrs, out) {
        
        if (attrs.onLoading) {
            out << "${attrs.onLoading};"
        }
        
        out << "Ext.Ajax.request({"

        if (attrs.method) {
            out << "method: '${attrs.remove('method')}', "
        }
        
        buildCallback(attrs, out)
        
        def jsParams = attrs.params?.findAll { it.value instanceof JavascriptValue }
        jsParams?.each { attrs.params?.remove(it.key) }
        
        // build url
        def url
        if (attrs.url) {
            url = taglib.createLink(attrs.url)
        }
        else {
            url = taglib.createLink(attrs)
        }
        attrs.remove('url')

        if (!attrs.params) attrs.params = [:]
        jsParams?.each { attrs.params[it.key] = it.value }
        
        def i = url?.indexOf('?')
        if (i >-1) {
            if (attrs.params instanceof String) {
                attrs.params += "+'&${url[i+1..-1].encodeAsJavaScript()}'"                
            }
            else if (attrs.params instanceof Map) {
                def params = createQueryString(attrs.params)
                attrs.params = "'${params}${params ? '&' : ''}${url[i+1..-1].encodeAsJavaScript()}'"
            }
            else {
            	attrs.params = []
                attrs.params = "'${url[i+1..-1].encodeAsJavaScript()}'"
            }
            out << "url: '${url[0..i-1]}'"
        }
        else {
            out << "url: '${url}'"
        }
        if (attrs.params) {
            def params = attrs.remove('params')
            if (params instanceof Map) {
                params = createQueryString(params)
                params = "'${params}'"
            }
            out << ", params: ${params}"
        }
        
        // add form for form submits
        if (attrs.forForm) {
            def form = attrs.remove('forForm')
            out << ", form: ${form}"
        }
        
        out << '});'
        
        // remove all onX callback events
        def callbacks = attrs.findAll { k, v ->
            k ==~ /on(\p{Upper}|\d){1}\w+/
        }
        callbacks.each { k, v ->
            attrs.remove(k)
        }
        
        attrs.remove('params')
    }

    // helper method to create callback object
    def buildCallback(attrs, out) {     
        
        // success
        out << 'success: function(response, options){'
        if (attrs.onLoaded) {
            out << "${attrs.onLoaded};"
        }
        if (attrs.update instanceof Map) {
            if (attrs.update?.success) {
                out << "Ext.get('${attrs.update.success}').dom.innerHTML = response.responseText;"
            }
        }
        else if (attrs.update) {
            out <<  "Ext.get('${attrs.update}').dom.innerHTML = response.responseText;"
        }
        if(attrs.onSuccess) {
            out << "${attrs.onSuccess};"
        }	
        if(attrs.onComplete) {
            out << "${attrs.onComplete};"
        }		  
        out << '}, '
        
        // failure
        out << 'failure: function(response, options){'									
        if (attrs.update instanceof Map) {
            if (attrs.update?.failure) {
                out << "Ext.get('${attrs.update.failure}').dom.innerHTML = response.statusText;"
            }
        }
        if (attrs.onFailure) {
            out << "${attrs.onFailure};"
        }	
        if (attrs.onComplete) {
            out << "${attrs.onComplete};"
        }													
        out << '}, '
    }
    
    private String createQueryString(params) {
        def allParams = []
        for (entry in params) {
            def value = entry.value
            def key = entry.key
            if (value instanceof JavascriptValue) {
                allParams << "${key.encodeAsURL()}='+${value.value}+'"
            }
            else {
                allParams << "${key.encodeAsURL()}=${value.encodeAsURL()}".encodeAsJavaScript()
            }
        }
        if (allParams.size() == 1) {
            return allParams[0]
        }
        else {
            return allParams.join('&')
        }
    }
    
    def prepareAjaxForm(attrs) {
        if (!attrs.forSubmitTag) attrs.forSubmitTag = ""
        
        attrs.forForm = "this${attrs.remove('forSubmitTag')}"
	}
}
