import java.text.SimpleDateFormat
import grails.converters.*;

class PlayerController {
    
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static def allowedMethods = [delete:'POST', save:'POST', update:'POST']

    // Start RESTful services
    def showREST = {
        def playerResource = Player.get(params.id)
        
        if (!playerResource) {
                playerResource = Player.list()
        }
        
        renderAsJSON(playerResource, true, true)
        
    }
    def showWithPlayerStatsREST = {
        def playerResource = Player.get(params.id)
        
        renderAsJSON(playerResource, true, false)
        
    }
    def showWithPlayerNewsREST = {
        def playerResource = Player.get(params.id)
        
        renderAsJSON(playerResource, false, true)
        
    }
    
    def showByTeamREST = {
            def teamResource = Team.get(params.id)
            def players = []
            
            if (teamResource) {
                players = Player.findAllByTeam(teamResource)
            }
            
            renderAsJSON(players, false, false)
         }
    
    def showByNameREST = {
        def nameCriteria = params.query
        def players = []
        
        if (nameCriteria) {
            def searchItems = nameCriteria.split(" ")
            
            if (searchItems.size() == 2) {
                players = Player.findAllByLastNameLikeAndFirstNameLike(searchItems[0] + "%", searchItems[1] + "%")
            } else { 
                // Assume just last name only
                players = Player.findAllByLastNameLike(searchItems[0] + "%")
            }
        }
        
        renderAsJSON(players, false, false)
     }
    
    def saveREST = {
        
    }
    
    private def renderAsJSON(def playerResource, boolean showStats, boolean showNews) {
        render(contentType:"text/json") {
            if (playerResource) {
                if (playerResource instanceof Player) {
                    def newsItems = playerResource.newsItems
                    def gameStats = playerResource.gameStats
                    
                    player (
                            id: String.valueOf(playerResource.id),
                            teamId: playerResource.team.id,
                            teamName: playerResource.team.name,
            			    number: playerResource.number,
            			    firstName: playerResource.firstName, 
            			    lastName: playerResource.lastName,
            			    heightFeet: playerResource.heightFeet,
            			    heightInches: playerResource.heightInches,
            			    weightInPounds: playerResource.weightInPounds,
            			    errors: playerResource.errors.getErrorCount() > 0 ? playerResource.errors.allErrors : [])
                    
                    if (showStats) {
                        playerStats (
                            {
                                for (stats in gameStats) {
                                    playerStats (
                			            gameId:  stats.game.id,
                			            goals: stats.goals,
                			            assists: stats.assists,
                			            plusMinus:  stats.plusMinus,
                			            hits: stats.hits,
                			            takeAways: stats.takeAways,
                			            scoringChances: stats.scoringChances,
                			            playResultedInGoalFor:  stats.playResultedInGoalFor,
                			            pims: stats.pims,
                			            giveAways: stats.giveAways,
                			            playResultedInGoalAgainst:  stats.playResultedInGoalAgainst
                			        )
                                }
                            }
                        )  
                    }
                        
                    if (showNews) {
                        playerNews (
                           {
                                for (newsItem in newsItems) {
                                    playerNews (
                			            newsDate:  newsItem.newsDate ? new SimpleDateFormat('yyyy-MM-dd').format(newsItem.newsDate) : '',
                			            news: newsItem.news
                			        )
                			    }
                            }
                		)
                    }
                } else {
                    players {
            			for(player in playerResource) {
            			    players (
        			            id: String.valueOf(player.id),
        			            teamId:  player.team.id,
        			            teamName:  player.team.name,
        			            number: player.number,
        			            firstName: player.firstName, 
        	    			    lastName: player.lastName,
        	    			    heightFeet: player.heightFeet, 
        	    			    heightInches: player.heightInches,
        	    			    weightInPounds: player.weightInPounds,
        	    			    errors: player.errors.getErrorCount() > 0 ? player.errors.allErrors : [])
            			}
            		}	
                }
        	} else {
        	    def result = []        
        	    render result as JSON
        	}
        } 
    }
    // End RESTful services
    
    def list = {
        if(!params.max) params.max = 10
        [ playerInstanceList: Player.list( params ) ]
    }

    def show = {
        def playerInstance = Player.get( params.id )

        if(!playerInstance) {
            flash.message = "Player not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ playerInstance : playerInstance ] }
    }

    def delete = {
        def playerInstance = Player.get( params.id )
        if(playerInstance) {
            playerInstance.delete()
            flash.message = "Player ${params.id} deleted"
            redirect(action:list)
        }
        else {
            flash.message = "Player not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def playerInstance = Player.get( params.id )

        if(!playerInstance) {
            flash.message = "Player not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ playerInstance : playerInstance ]
        }
    }

    def update = {
        def playerInstance = Player.get( params.id )
        if(playerInstance) {
            playerInstance.properties = params
            if(!playerInstance.hasErrors() && playerInstance.save()) {
                flash.message = "Player ${params.id} updated"
                redirect(action:show,id:playerInstance.id)
            }
            else {
                render(view:'edit',model:[playerInstance:playerInstance])
            }
        }
        else {
            flash.message = "Player not found with id ${params.id}"
            redirect(action:edit,id:params.id)
        }
    }

    def create = {
        def playerInstance = new Player()
        playerInstance.properties = params
        return ['playerInstance':playerInstance]
    }

    def save = {
        def playerInstance = new Player(params)
        if(!playerInstance.hasErrors() && playerInstance.save()) {
            flash.message = "Player ${playerInstance.id} created"
            redirect(action:show,id:playerInstance.id)
        }
        else {
            render(view:'create',model:[playerInstance:playerInstance])
        }
    }
}
