class TeamController {
    def authenticateService 
    
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static def allowedMethods = [delete:'POST', save:'POST', update:'POST']
    
    // Start RESTful Services
    def showREST = {
        def teamResource = Team.get(params.id)
        def principal
        
        if (authenticateService) {
            principal = authenticateService.principal()
        }
        
        if (!teamResource) {
            if (principal) {
                teamResource = filterByPrincipal(principal)
            } else {
                teamResource = Team.list()
            }
        }
        
        renderAsJSON(teamResource)
        
    }
    
    def saveREST = {
        
    }
    
    private def filterByPrincipal(def principal) {
        User user = User.findByUsername(principal.getUsername())
        
        def teams = user ? Team.findAll("FROM Team t WHERE :user IN ELEMENTS(t.users)", [user:user]) : []
        
        return teams
    }
    
    private def renderAsJSON(def teamResource) {
        render(contentType:"text/json") {
            if (teamResource instanceof Team) {
                team (
    			    id: String.valueOf(teamResource.id),
    			    leagueId: teamResource.league.id,
    			    name: teamResource.name, 
    			    playsIn: teamResource.playsIn,
    			    playsInArena: teamResource.playsInArena,
    			    errors: teamResource.errors.getErrorCount() > 0 ? teamResource.errors.allErrors : [])
            } else {
                teams {
        			for(team in teamResource) {
        			    teams (
        			            id: String.valueOf(team.id),
        	    			    name: team.name, 
        	    			    playsIn: team.playsIn,
        	    			    playsInArena: team.playsInArena,
        	    			    errors: team.errors.getErrorCount() > 0 ? team.errors.allErrors : [])
        			}
        		}	
            }
    	}
    }
    
    // End RESTful Services

    def list = {
        if(!params.max) params.max = 10
        [ teamInstanceList: Team.list( params ) ]
    }

    def show = {
        def teamInstance = Team.get( params.id )

        if(!teamInstance) {
            flash.message = "Team not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ teamInstance : teamInstance ] }
    }

    def delete = {
        def teamInstance = Team.get( params.id )
        if(teamInstance) {
            teamInstance.delete()
            flash.message = "Team ${params.id} deleted"
            redirect(action:list)
        }
        else {
            flash.message = "Team not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def teamInstance = Team.get( params.id )

        if(!teamInstance) {
            flash.message = "Team not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ teamInstance : teamInstance ]
        }
    }

    def update = {
        def teamInstance = Team.get( params.id )
        if(teamInstance) {
            teamInstance.properties = params
            if(!teamInstance.hasErrors() && teamInstance.save()) {
                flash.message = "Team ${params.id} updated"
                redirect(action:show,id:teamInstance.id)
            }
            else {
                render(view:'edit',model:[teamInstance:teamInstance])
            }
        }
        else {
            flash.message = "Team not found with id ${params.id}"
            redirect(action:edit,id:params.id)
        }
    }

    def create = {
        def teamInstance = new Team()
        teamInstance.properties = params
        return ['teamInstance':teamInstance]
    }

    def save = {
        def teamInstance = new Team(params)
        if(!teamInstance.hasErrors() && teamInstance.save()) {
            flash.message = "Team ${teamInstance.id} created"
            redirect(action:show,id:teamInstance.id)
        }
        else {
            render(view:'create',model:[teamInstance:teamInstance])
        }
    }
}
