import java.text.SimpleDateFormat
import grails.converters.*;

class LeagueController {
    
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static def allowedMethods = [delete:'POST', save:'POST', update:'POST', saveREST: 'POST']

    // START RESTful services  
    def showREST = {
        def leagueResource = League.get( params.id )
        
        if (!leagueResource) {
            leagueResource = League.list()
        }
    
        renderAsJSON(leagueResource)
    }
    
    def saveREST = {
        def leagueId = params.id
        def leagueResource = null
        
        if (leagueId) {
            leagueResource = League.get( leagueId )
        }
        if(leagueResource) {
            leagueResource.properties = params
        }
        else {
            leagueResource = new League(params)
            
        }
        
        def success = false
        if(!leagueResource.hasErrors()) {
           if(leagueResource.save()) {
               success = true
           }
        }
        
        renderSaveAsJSON(leagueResource, success)
    }  
    
    private def renderAsJSON(def leagueResource) {
        render(contentType:"text/json") {
            if (leagueResource instanceof League) {
                league (
    			    id: String.valueOf(leagueResource.id),
    			    name: leagueResource.name, 
    			    description: leagueResource.description,
    			    sinceDate: leagueResource.sinceDate ? new SimpleDateFormat('yyyy-MM-dd').format(leagueResource.sinceDate) : '',
    			    errors: leagueResource.errors.getErrorCount() > 0 ? leagueResource.errors.allErrors : [])
            } else {
                leagues {
        			for(league in leagueResource) {
        			    leagues (
        			        id: String.valueOf(league.id), 
            			    name: league.name, 
            			    description: league.description, 
            			    sinceDate: league.sinceDate ? new SimpleDateFormat('yyyy-MM-dd').format(league.sinceDate) : '',
            			    errors: league.errors.getErrorCount() > 0 ? league.errors.allErrors : [])
        			}
        		}	
            }
    	}
    }
    
    /**
     * Return success as part of the result to indicate that the POST save was good.
     */
    private def renderSaveAsJSON(League leagueResource, boolean success) {
        // Build the custom result to return whether the save was successful or not
        def result = [
              success:success ? 'true' : 'false', 
              league:[
                id: String.valueOf(leagueResource.id),
                name: leagueResource.name, 
                description: leagueResource.description,
                sinceDate: leagueResource.sinceDate ? new SimpleDateFormat('yyyy-MM-dd').format(leagueResource.sinceDate) : '',
                errors: leagueResource.errors.getErrorCount() > 0 ? leagueResource.errors.allErrors : []
              ]
        ]        
        render result as JSON
        
    }
    // END RESTful Services
    
    def list = {
        if(!params.max) params.max = 10
        [ leagueInstanceList: League.list( params ) ]
    }

    def show = {
        def leagueInstance = League.get( params.id )

        if(!leagueInstance) {
            flash.message = "League not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ leagueInstance : leagueInstance ] }
    }

    def delete = {
        def leagueInstance = League.get( params.id )
        if(leagueInstance) {
            leagueInstance.delete()
            flash.message = "League ${params.id} deleted"
            redirect(action:list)
        }
        else {
            flash.message = "League not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def leagueInstance = League.get( params.id )

        if(!leagueInstance) {
            flash.message = "League not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ leagueInstance : leagueInstance ]
        }
    }

    def update = {
        def leagueInstance = League.get( params.id )
        if(leagueInstance) {
            leagueInstance.properties = params
            if(!leagueInstance.hasErrors() && leagueInstance.save()) {
                flash.message = "League ${params.id} updated"
                redirect(action:show,id:leagueInstance.id)
            }
            else {
                render(view:'edit',model:[leagueInstance:leagueInstance])
            }
        }
        else {
            flash.message = "League not found with id ${params.id}"
            redirect(action:edit,id:params.id)
        }
    }

    def create = {
        def leagueInstance = new League()
        leagueInstance.properties = params
        return ['leagueInstance':leagueInstance]
    }

    def save = {
        def leagueInstance = new League(params)
        if(!leagueInstance.hasErrors() && leagueInstance.save()) {
            flash.message = "League ${leagueInstance.id} created"
            redirect(action:show,id:leagueInstance.id)
        }
        else {
            render(view:'create',model:[leagueInstance:leagueInstance])
        }
    }
}
