import java.text.SimpleDateFormat
import grails.converters.*;

class ScoutingReportController {
    def authenticateService
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static def allowedMethods = [delete:'POST', save:'POST', update:'POST']

    // Start RESTful services
    def showREST = {
        def reportResource = ScoutingReport.get(params.id)
        def principal
        
        if (authenticateService) {
            principal = authenticateService.principal()
        }
        
        if (!reportResource) {
            if (principal) {
                reportResource = filterByPrincipal(principal)
            } else {
                reportResource = ScoutingReport.list()
            }
        }
        
        renderAsJSON(reportResource)
        
    }
    
    def saveREST = {
        def reportResource = ScoutingReport.get(params.id)
        def principal
        
        if (authenticateService) {
            principal = authenticateService.principal()
        }
        
        def user = principal ? User.findByUsername(principal.getUsername()) : User.get(params.userId)
                
        if (!reportResource && user) {
            Long playerId = Long.parseLong(params.playerId)
            reportResource = ScoutingReport.find("from ScoutingReport as report \
                    inner join report.scout as user \
                    inner join report.player as player \
                    where player.id = :playerId \
                    and user.id = :userId", [playerId:playerId, userId: user.id])
                    
            if (reportResource) {
                // Expect a tuple of object back.  Just need the report
                reportResource = reportResource[0]
            }
        }
        
        if (reportResource && reportResource.scout.username == user.username) {
            reportResource.properties = params
            renderSaveAsJSON(true)
        } else {
            reportResource = new ScoutingReport(params)   
            
            def player = Player.get(params.playerId)
            def success = addToUser(reportResource, player, user)
            
            renderSaveAsJSON(success)
        }
    }
    
    private def filterByPrincipal(def principal) {
        User user = User.findByUsername(principal.getUsername())
        
        def scoutingReports = user ? ScoutingReport.findAllByScout(user) : []
        return scoutingReports
    }
    
    private def addToUser(def report, def player, def user) {
        def success = false
        
        if (user && player) {
            report.player = player
            user.addToScoutingReports(report)
            
           if(user.save()) {
               success = true
           } else {
               user.errors.each {println (it)}
           }
        }
        
        return success
    }
    

    
    String generalNotes
    String strengths
    String weaknesses
    String tendencies
    
    BigDecimal ratingSkating = 0.0
    BigDecimal ratingPuckControl = 0.0
    BigDecimal ratingPhysicalPlay = 0.0
    BigDecimal ratingSize = 0.0
    BigDecimal ratingHockeySense = 0.0
    BigDecimal ratingIntensity = 0.0
    BigDecimal ratingOffensivePlay = 0.0
    BigDecimal ratingDefensivePlay =0.0
    
    private def renderAsJSON(def reportResource) {
        render(contentType:"text/json") {
            if (reportResource instanceof ScoutingReport) {
                def notes = reportResource.scoutingNotes
                
                scoutingReport (
                        id: String.valueOf(reportResource.id),
                        teamId: reportResource.player.team.id,
                        playerId:  reportResource.player.id,
                        number: reportResource.player.number,
                        firstName: reportResource.player.firstName,
                        lastName: reportResource.player.lastName,
                        generalNotes: reportResource.generalNotes,
        			    strengths: reportResource.strengths,
        			    weaknesses: reportResource.weaknesses, 
        			    tendencies: reportResource.tendencies,
        			    ratingSkating: reportResource.ratingSkating,
        			    ratingPuckControl: reportResource.ratingPuckControl,
        			    ratingPhysicalPlay: reportResource.ratingPhysicalPlay,
        			    ratingSize: reportResource.ratingSize,
        			    ratingHockeySense: reportResource.ratingHockeySense,
        			    ratingIntensity: reportResource.ratingIntensity,
        			    ratingOffensivePlay: reportResource.ratingOffensivePlay,
        			    ratingDefensivePlay: reportResource.ratingDefensivePlay,
        			    errors: reportResource.errors.getErrorCount() > 0 ? reportResource.errors.allErrors : [])
                
                scoutingNotes (
                    {
                        for (note in notes) {
                            scoutingNotes (
        			            id:  note.id,
        			            note: note.note,
        			            dateLogged: note.dateLogged ? new SimpleDateFormat('yyyy-MM-dd').format(note.dateLogged) : ''
        			        )
                        }
                    }
                )  
            } else {
                scoutingReports {
        			for(report in reportResource) {
        			    scoutingReports (
        			            id: String.valueOf(report.id),
                                teamId: report.player.team.id,
                                playerId:  report.player.id,
                                number: report.player.number,
                                firstName: report.player.firstName,
                                lastName: report.player.lastName,
                                generalNotes: report.generalNotes,
                			    strengths: report.strengths,
                			    weaknesses: report.weaknesses, 
                			    tendencies: report.tendencies,
                			    ratingSkating: report.ratingSkating,
                			    ratingPuckControl: report.ratingPuckControl,
                			    ratingPhysicalPlay: report.ratingPhysicalPlay,
                			    ratingSize: report.ratingSize,
                			    ratingHockeySense: report.ratingHockeySense,
                			    ratingIntensity: report.ratingIntensity,
                			    ratingOffensivePlay: report.ratingOffensivePlay,
                			    ratingDefensivePlay: report.ratingDefensivePlay,
                			    errors: report.errors.getErrorCount() > 0 ? report.errors.allErrors : [])
        			}
        		}	
            }
    	}
    }
    
    def renderSaveAsJSON(success) {
        def result = [
              success:success ? 'true' : 'false'
        ]        
        render result as JSON
    }
    
    // End RESTful services
    
    def list = {
        if(!params.max) params.max = 10
        [ scoutingReportInstanceList: ScoutingReport.list( params ) ]
    }

    def show = {
        def scoutingReportInstance = ScoutingReport.get( params.id )

        if(!scoutingReportInstance) {
            flash.message = "ScoutingReport not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ scoutingReportInstance : scoutingReportInstance ] }
    }

    def delete = {
        def scoutingReportInstance = ScoutingReport.get( params.id )
        if(scoutingReportInstance) {
            scoutingReportInstance.delete()
            flash.message = "ScoutingReport ${params.id} deleted"
            redirect(action:list)
        }
        else {
            flash.message = "ScoutingReport not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def scoutingReportInstance = ScoutingReport.get( params.id )

        if(!scoutingReportInstance) {
            flash.message = "ScoutingReport not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ scoutingReportInstance : scoutingReportInstance ]
        }
    }

    def update = {
        def scoutingReportInstance = ScoutingReport.get( params.id )
        if(scoutingReportInstance) {
            scoutingReportInstance.properties = params
            if(!scoutingReportInstance.hasErrors() && scoutingReportInstance.save()) {
                flash.message = "ScoutingReport ${params.id} updated"
                redirect(action:show,id:scoutingReportInstance.id)
            }
            else {
                render(view:'edit',model:[scoutingReportInstance:scoutingReportInstance])
            }
        }
        else {
            flash.message = "ScoutingReport not found with id ${params.id}"
            redirect(action:edit,id:params.id)
        }
    }

    def create = {
        def scoutingReportInstance = new ScoutingReport()
        scoutingReportInstance.properties = params
        return ['scoutingReportInstance':scoutingReportInstance]
    }

    def save = {
        def scoutingReportInstance = new ScoutingReport(params)
        if(!scoutingReportInstance.hasErrors() && scoutingReportInstance.save()) {
            flash.message = "ScoutingReport ${scoutingReportInstance.id} created"
            redirect(action:show,id:scoutingReportInstance.id)
        }
        else {
            render(view:'create',model:[scoutingReportInstance:scoutingReportInstance])
        }
    }
}
