class PlayerControllerTests extends GroovyTestCase {
    void testPlayerJSON() {
        def playerController = new PlayerController()
        
        initTestData();
        
        def player = Player.findByLastName('Gaborik')
        playerController.params.id = player.id
        playerController.showREST();
        println(playerController.response.contentAsString)
    }
    
    void testPlayerListJSON() {
        def playerController = new PlayerController()
        
        initTestData();
        
        playerController.showREST();
        println(playerController.response.contentAsString)
    }
    
    void testPlayersByTeamJSON() {
        def playerController = new PlayerController()
        
        initTestData();
        
        def team = Team.findByName('Minnesota Wild')
        playerController.params.id = team.id
        playerController.showByTeamREST();
        println(playerController.response.contentAsString)
    }
    
    void testPlayersByDevilsJSON() {
        def playerController = new PlayerController()
        
        initTestData();
        
        def team = Team.findByName('New Jersey Devils')
        playerController.params.id = team.id
        playerController.showByTeamREST();
        println(playerController.response.contentAsString)
    }
    
    void testPlayersByLastNameJSON() {
        def playerController = new PlayerController()
        
        initTestData();
        
        playerController.params.query = "Gabor"
        playerController.showByNameREST();
        println(playerController.response.contentAsString)
    }
    
    void testPlayersByLastNameAndFirstNameJSON() {
        def playerController = new PlayerController()
        
        initTestData();
        
        playerController.params.query = "Brodeur M"
        playerController.showByNameREST();
        println(playerController.response.contentAsString)
    }
    
    private void initTestData() {
        League nhl = TestDataCreator.createNHL()
        Season season = TestDataCreator.createSeason(2008, 2009)
        Team mnWild = TestDataCreator.createTeamMnWild()
        Team njDevils = TestDataCreator.createTeamNJDevils()
        Player gaborik = TestDataCreator.createMarianGaborik()
        Player brodeur = TestDataCreator.createMartinBrodeur()
        
        
        nhl.addToTeams(mnWild)
        nhl.addToTeams(njDevils)
        nhl.addToSeasons(season)
        nhl.save()
        
        // Ensure a game is saved
        Game game = TestDataCreator.createGame()
        game.season = season
        game.homeTeam = mnWild
        game.visitorTeam = njDevils
        game.save()
        
        // Save the player with stats
        PlayerStats stats = new PlayerStats(goals: 2, assists: 1)
        stats.game = game
        
        Date newsDate = new GregorianCalendar(2009, Calendar.FEBRUARY, 20).time
        PlayerNews newsItem = new PlayerNews(newsDate:newsDate, news: 'This is not news')
        
        gaborik.team = mnWild
        gaborik.addToGameStats(stats)
        gaborik.addToNewsItems(newsItem)
        gaborik.save(flush:true)
        
        brodeur.team = njDevils
        brodeur.save(flush:true)
    }
}
