import java.util.GregorianCalendar
class PlayerTests extends GroovyTestCase {

    void testPlayerAddStats() {
        League nhl = TestDataCreator.createNHL()
        Season season = TestDataCreator.createSeason(2008, 2009)
        Team mnWild = TestDataCreator.createTeamMnWild()
        Team njDevils = TestDataCreator.createTeamNJDevils()
        Player gaborik = TestDataCreator.createMarianGaborik()
        
        
        nhl.addToTeams(mnWild)
        nhl.addToTeams(njDevils)
        nhl.addToSeasons(season)
        nhl.save()
        
        // Ensure a game is saved
        Game game = TestDataCreator.createGame()
        game.season = season
        game.homeTeam = mnWild
        game.visitorTeam = njDevils
        game.save()
        
        // Save the player with stats
        PlayerStats stats = new PlayerStats(goals: 2, assists: 1)
        stats.game = game
        
        gaborik.team = mnWild
        gaborik.addToGameStats(stats)
        gaborik.save(flush:true)
        
        assertEquals 1, Player.list().size()
        assertEquals 1, PlayerStats.list().size()
    }
    
    void testPlayerAddNews() {
        League nhl = TestDataCreator.createNHL()
        Team mnWild = TestDataCreator.createTeamMnWild()
        Player gaborik = TestDataCreator.createMarianGaborik()
        
        
        nhl.addToTeams(mnWild)
        nhl.save()
        
        // Save the player with stats
        Date newsDate = new GregorianCalendar(2009, Calendar.FEBRUARY, 20).time
        
        PlayerNews newsItem = new PlayerNews(newsDate:newsDate, news: 'This is not news')
        
        gaborik.team = mnWild
        gaborik.addToNewsItems(newsItem)
        gaborik.save(flush:true)
        
        assertEquals 1, Player.list().size()
        assertEquals 1, PlayerNews.list().size()
        
    }
}
