Ext.namespace('hockeystats.form');

hockeystats.form.LeagueForm = function(config) {
    var formConfig = config ? config : {};
    
    // Add the record to the config.  This will be used to dynamically add records to the store (a.k.a:  blank record)
    var leagueRecord = Ext.data.Record.create([
        {
            name: 'name'
        }, 
        {
            name: 'description'
        }, 
        {
            name: 'sinceDate'
        }, 
        {
            name: 'id'
        }]);
    
    // Cannot Just use a JsonStore for this.  The Combobox sends a POST request when using a JsonStore.
    // Must use the specialized HttpProxy to ensure a GET is called (RESTful)
    var httpProxy = new Ext.data.HttpProxy(
        {
            url: HockeyStats.LEAGUE_REST_URL,
            method: 'GET'
        });
    
    var reader = new Ext.data.JsonReader(
        {
            root: 'leagues',
            id: 'id'
        }, leagueRecord);
    
    var leagueStore = new Ext.data.Store(
        {
            proxy: httpProxy,
            reader: reader,
            listeners: 
                {
                    // Insert a blank record to the store for adding a new League
                    'load': 
                        {
                            fn: function(store, records, options) {
                                var record = leagueRecord;
                                store.insert(0, [new record(
                                    {
                                        id: '',
                                        name: '[Create New League]',
                                        description: '',
                                        sinceDate: ''
                                    })]);
                            }
                        }
                }
        });
    
    var formPanel = this; // Need this reference for the handler
    Ext.apply(formConfig, 
        {
            url: HockeyStats.LEAGUE_REST_URL,
            title: 'League Information',
            width: 450,
            frame: true,
			collapsible: true,
            cls: 'league-form',
            monitorValid: true,
            items: [
            
                {
                    xtype: 'combo',
                    triggerAction: 'all',
                    fieldLabel: 'Available Leagues',
                    displayField: 'name',
                    valueField: 'id',
                    name: 'leagueId',
                    hiddenName: 'id',
                    store: leagueStore,
                    loadingText: 'Fetching Leagues',
                    listeners: 
                        {
                            'select': 
                                {
                                    fn: function(combo, record, index) {
                                        // Set the form values
                                        var nameField = this.form.items.get(1);
                                        var descField = this.form.items.get(2);
                                        var sinceDateField = this.form.items.get(3);
                                        
                                        // Set the name, description, since date
                                        nameField.setRawValue(record.get("name"));
                                        descField.setRawValue(record.get("description"));
                                        sinceDateField.setRawValue(record.get("sinceDate"));
                                    },
                                    scope: this
                                }
                        }
                }, 
            
                {
                    xtype: 'fieldset',
                    title: 'League Info',
                    autoHeight: true,
                    collapsible: true,
                    items: [
                        {
                            xtype: 'textfield',
							allowBlank: false, // This field is required
                            fieldLabel: 'Name',
                            name: 'name',
                            width: 300
                        }, 
                        {
                            xtype: 'textfield',
                            fieldLabel: 'Description',
							allowBlank: false, // This field is required
                            name: 'description',
                            width: 300
                        }, 
                        {
                            xtype: 'datefield',
                            fieldLabel: 'Since',
                            name: 'sinceDate',
                            width: 150
                        }]
                }],
            
            buttons: [
                {
                    text: 'Save',
                    formBind: true, // Used so that the button is only enabled when validation passes.
                    handler: function() {
                        // Submit the form.  On success reload the form
                        formPanel.getForm().submit(
                            {
                                success: function(f, a) {
                                    Ext.Msg.alert("Submit Status", "We Saved the League!!");
                                    
                                    leagueStore.load();
                                },
                                
                                failure: function(f, a) {
                                    Ext.MessageBox.alert("Submit Status", "Something bad happened!!");
                                }
                            });
                    }
                }, 
                {
                    text: 'Cancel'
                }]
        
        });
    
    hockeystats.form.LeagueForm.superclass.constructor.call(this, formConfig)
}

Ext.extend(hockeystats.form.LeagueForm, Ext.FormPanel, {});

Ext.reg('hockeystats.form.LeagueForm', hockeystats.form.LeagueForm);
