Ext.namespace('hockeystats.util');

/**
 * DomUtil.js
 */
hockeystats.util.DomUtil = function(config) {
    function _timeoutFn(message, intervalId, timeoutId) {
        Ext.MessageBox.alert('Timeout', message);

        // Stop trying to fetch the data
        clearInterval(intervalId);
        clearTimeout(timeoutId);
    };

    function _timeoutReadyFn(component, intervalId, timeoutId) {
        var componentDesc = component.getXType() ? component.getXType() : component;
        _timeoutFn('Timeout waiting for component to be ready.', intervalId, timeoutId);
    };
    function _timeoutDomFn(component, intervalId, timeoutId) {
        var componentDesc = component.getXType() ? component.getXType() : component;
        _timeoutFn('Timeout waiting for component DOM to be available.', intervalId, timeoutId);
    };

    function _timeoutConditionFn(intervalId, timeoutId) {
        _timeoutFn('Timeout waiting for condition.', intervalId, timeoutId);
    };

    function _callConditionFn(fnConfig) {
        // Call the function and clear the interval
        if (Ext.type(fnConfig.scope)) {
            return fnConfig.fn.call(fnConfig.scope);
        } else {
            return fnConfig.fn();
        }
    };

    function _callFunction(fnConfig, intervalId, timeoutId) {
        // Call the function and clear the interval
        if (Ext.type(fnConfig.scope)) {
            fnConfig.fn.call(fnConfig.scope);
        } else {
            fnConfig.fn();
        }

        if (!!intervalId) {
            clearInterval(intervalId);
        }
        if (!!timeoutId) {
            clearTimeout(timeoutId);
        }
    };

    function _isDomAvailable(domElId) {
        if (Ext.type(domElId)) {
            var element = Ext.get(domElId);
            return Ext.type(element) && Ext.type(element.dom)
        } else {
            return false;
        }
    };


    // Public Utility Functions
    return {

        /**
         * If the component has the DOM available, either through a custom isDomAvailable function or
         * inspecting the component's element and dom the passed in function will be invoked.
         */
        onDomAvailable: function(component, fnConfig, intervalMillis, timeoutMillis) {
            var onDomAvailableIntervalFn = function() {
                var isDomAvailable = _isDomAvailable(component);

                if (isDomAvailable) {
                    _callFunction(fnConfig, intervalId, timeoutId);
                }

                return isDomAvailable;
            };

            // Call the interval and timeout
            if (!onDomAvailableIntervalFn()) {
                var onDomAvailableTimeoutFn = function() {
                    _timeoutDomFn(component, intervalId, timeoutId);
                };
                var intervalId = setInterval(onDomAvailableIntervalFn, intervalMillis);
                var timeoutId = setTimeout(onDomAvailableTimeoutFn, timeoutMillis);
            }
        },

        /**
         * This method invokes the target function when the condition function returns true.
         */
        onConditionTrue: function(conditionFnConfig, fnConfig, intervalMillis, timeoutMillis) {
            var onConditionTrueFn = function() {
                var booleanReturn = _callConditionFn(conditionFnConfig);

                // Only call the function when the boolean result is false
                if (Ext.type(booleanReturn) === 'boolean' && booleanReturn) {
                    _callFunction(fnConfig, intervalId, timeoutId);
                }

                return booleanReturn;
            }

            // Call the interval and timeout
            if (!onConditionTrueFn()) {
                var onConditionTrueTimeoutFn = function() {
                    _timeoutConditionFn(intervalId, timeoutId);
                };
                var intervalId = setInterval(onConditionTrueFn, intervalMillis);
                var timeoutId = setTimeout(onConditionTrueTimeoutFn, timeoutMillis);
            }
        }
    }
}();
