/**
 * @author tlomenda
 */
Ext.namespace('hockeystats.panel');

hockeystats.panel.PlayerSearchPanel = function(config) {

    function _createPlayerSearchCombo() {
        var playerRecord = Ext.data.Record.create([{
            name: 'id'
        }, {
            name: 'number'
        }, {
            name: 'firstName'
        }, {
            name: 'lastName'
        }, {
            name: 'teamId'
        }, {
            name: 'teamName'
        }]);
        
        var httpProxy = new Ext.data.HttpProxy({
            url: HockeyStats.PLAYER_REST_URL + "/name",
            method: 'POST'
        });
        
        var reader = new Ext.data.JsonReader({
            root: 'players',
            id: 'id',
            number: 'number',
            firstName: 'firstName',
            lastName: 'lastName',
            teamId: 'teamId',
            teamName: 'teamName'
        }, playerRecord);
        
        // Custom Renderer for the Results
        var resultTpl = new Ext.XTemplate('<tpl for="."><div class="player-search-item" id="player-search-item-{id}">', '<h3>{number} {firstName} {lastName}</h3>', '({teamName})', '</div></tpl>');
		
        var playerSearchStore = new Ext.data.Store({
            proxy: httpProxy,
            reader: reader,
            listeners: {
                load: {
                    fn: function(store, records, options) {
                        
                        for (var i = 0; i < records.length; i++) {
                            var record = store.getAt(i);
							var playerId = record.get('id');
                            var itemElementId = 'player-search-item-' + playerId
                            
                            hockeystats.util.DomUtil.onDomAvailable(itemElementId, {
                                fn: function() {
                                    new Ext.dd.DragSource(itemElementId, {playerId: playerId});
                                }
                            }, 10, 10000);
                        }
                    },
                    scope: this
                }
            }
        });
        
        var search = new Ext.form.ComboBox({
            store: playerSearchStore,
            typeAhead: false,
            loadingText: 'Searching...',
            cls: 'player-search-combo',
            pageSize: 10,
            minChars: 1, // Should change to 3 or more
            hideTrigger: true,
            tpl: resultTpl,
            itemSelector: 'div.player-search-item'
        });
        
        return search;
    }
    
    
    var panelConfig = config ? config : {};
    
    var playerSearchCombo = _createPlayerSearchCombo();
    Ext.apply(panelConfig, {
        autoWidth: true,
        cls: 'player-search-panel',
        items: [{
            html: '<h3>Player Search</h3>'
        }, playerSearchCombo]
    });
    
    
    hockeystats.panel.PlayerSearchPanel.superclass.constructor.call(this, panelConfig);
}

Ext.extend(hockeystats.panel.PlayerSearchPanel, Ext.Panel, {    // Nothing to extend on this panel
});

Ext.reg('hockeystats.panel.PlayerSearchPanel', hockeystats.panel.PlayerSearchPanel);
