/**
 * @author tlomenda
 */
Ext.namespace('hockeystats.panel');

hockeystats.panel.PlayerWatchListPanel = function(config) {

    var panelConfig = config ? config : {};
    
    Ext.apply(panelConfig, {
        useArrows: true,
        id: 'playerwatch-tree',
        loader: new hockeystats.panel.PlayerWatchListTreeLoader(),
        
        root: {
            nodeType: 'async',
            text: 'My Player Watch List',
            draggable: false,
            id: 'extPlayerListRootNode'
        }
    
    });
    
    // Add the drop target for drag and drop (We expect to have the watch tree available
    var playerWatchTreePanel = this;
    var dropFunction = function() {
        return function(source, e, data) {
            var successFn = function(response) {
                this.getLoader().on('load', function(loader, node, response) {
					node.expand();
				}, this, {
					single: true
				});
				this.getLoader().load(this.getRootNode());
				
				
            };
            
            // Post to add a new report and then reload the tree
			var playerId = source.playerId;
            Ext.Ajax.request({
                url: HockeyStats.SCOUT_REPORT_REST_URL,
                method: 'POST',
                params: 'playerId=' + playerId,
                success: successFn.createDelegate(playerWatchTreePanel),
                failure: function(response) {
                    Ext.MessageBox.alert("Adding Player to Watch List", "The player with id '" + playerId + "'could not be added :-(");
                }
            });
			
			return true;
        }
    }();
    
    hockeystats.util.DomUtil.onDomAvailable('playerwatch-tree', {
        fn: function() {
            new Ext.dd.DropTarget('playerwatch-tree', {
                notifyDrop: dropFunction
            });
        }
    }, 10, 10000);
    
    
    
    hockeystats.panel.PlayerWatchListPanel.superclass.constructor.call(this, panelConfig);
}

Ext.extend(hockeystats.panel.PlayerWatchListPanel, Ext.tree.TreePanel, {});
Ext.reg('hockeystats.panel.PlayerWatchListPanel', hockeystats.panel.PlayerWatchListPanel);

/*
 * Override TreeLoader so that the player watch list JSON response is converted to a node list
 */
hockeystats.panel.PlayerWatchListTreeLoader = function(config) {

    function _generatePlayerWatchNodes(playersJson) {
        var playerWatchNodes = [];
        
        if (Ext.isArray(playersJson.scoutingReports)) {
            for (var i = 0; i < playersJson.scoutingReports.length; i++) {
                var report = playersJson.scoutingReports[i];
                var playerWatchNode = {
                    id: report.id + '-' + report.playerId,
                    text: report.number + ' - ' + report.firstName + ' ' + report.lastName,
                    icon: HockeyStats.BASE_URL + '/images/hockeystats/player.gif',
                    leaf: true
                };
                
                playerWatchNodes.push(playerWatchNode);
            }
        }
        
        return Ext.util.JSON.encode(playerWatchNodes);
    }
    
    var loaderConfig = config ? config : {};
    
    Ext.apply(loaderConfig, {
        requestMethod: 'GET',
        dataUrl: HockeyStats.SCOUT_REPORT_REST_URL,
        generatePlayerWatchNodes: _generatePlayerWatchNodes
    });
    
    hockeystats.panel.PlayerWatchListTreeLoader.superclass.constructor.call(this, loaderConfig);
}

Ext.extend(hockeystats.panel.PlayerWatchListTreeLoader, Ext.tree.TreeLoader, {
    // Override TreeLoader functionality to ensure that a response in the expected form is returned.
    processResponse: function(response, node, callback) {
    
        // Transfer the response for the tree panel
        var json = Ext.util.JSON.decode(response.responseText);
        
        if (Ext.type(json.scoutingReports)) {
            Ext.apply(response, {
                responseText: this.generatePlayerWatchNodes(json)
            });
        }
        
        hockeystats.panel.PlayerWatchListTreeLoader.superclass.processResponse.call(this, response, node, callback);
    }
});


