/**
 * @author tlomenda
 */
Ext.namespace('hockeystats.panel');

hockeystats.panel.TeamListPanel = function(config) {

    var panelConfig = config ? config : {};
    
    Ext.apply(panelConfig, {
		useArrows:true,

        loader: new hockeystats.panel.TeamListTreeLoader(),
        
        root: {
			nodeType: 'async',
            text: 'My Team List',
            draggable: false,
            id: 'extTeamListRootNode'
        }
    
    });
    
    hockeystats.panel.TeamListPanel.superclass.constructor.call(this, panelConfig);
}

Ext.extend(hockeystats.panel.TeamListPanel, Ext.tree.TreePanel, {});
Ext.reg('hockeystats.panel.TeamListPanel', hockeystats.panel.TeamListPanel);

/*
 * Override TreeLoader so that the team list JSON response is converted to a node list
 */
hockeystats.panel.TeamListTreeLoader = function(config) {

    function _generateTeamNodes(teamsJson) {
        var teamNodes = [];
        
        if (Ext.isArray(teamsJson.teams)) {
            for (var i = 0; i < teamsJson.teams.length; i++) {
                var team = teamsJson.teams[i];
                var teamNode = {
                    id: team.id,
					icon: HockeyStats.BASE_URL + '/images/hockeystats/playerHelmet.gif',
                    text: team.name
                }
                
                teamNodes.push(teamNode);
            }
        }
        
        return Ext.util.JSON.encode(teamNodes);
    }
    
    function _generatePlayerNodes(playersJson) {
        var playerNodes = [];
        
        if (Ext.isArray(playersJson.players)) {
            for (var i = 0; i < playersJson.players.length; i++) {
                var player = playersJson.players[i];
                var playerNode = {
                    id: player.teamId + '-' + player.id,
                    text: player.number + ' - ' + player.firstName + ' ' + player.lastName,
					icon: HockeyStats.BASE_URL + '/images/hockeystats/player.gif',
                    leaf: true
                };
				
				playerNodes.push(playerNode);
            }
        }
        
        return Ext.util.JSON.encode(playerNodes);
    }
    
    var loaderConfig = config ? config : {};
    
    Ext.apply(loaderConfig, {
		requestMethod: 'GET',
		dataUrl: HockeyStats.TEAM_REST_URL,
        teamUrl: HockeyStats.TEAM_REST_URL,
        playerUrl: HockeyStats.PLAYER_REST_URL + '/team/',
        generatePlayerNodes: _generatePlayerNodes,
        generateTeamNodes: _generateTeamNodes
    });
    
    hockeystats.panel.TeamListTreeLoader.superclass.constructor.call(this, loaderConfig);
}

Ext.extend(hockeystats.panel.TeamListTreeLoader, Ext.tree.TreeLoader, {
    // Override TreeLoader functionality to ensure that a response in the expected form is returned.
    
    requestData: function(node, callback) {
        if (node.id === 'extTeamListRootNode') {
            this.dataUrl = this.teamUrl;
        }
        else {
            this.dataUrl = this.playerUrl + node.id;
        }
        
        hockeystats.panel.TeamListTreeLoader.superclass.requestData.call(this, node, callback);
    },
    
    processResponse: function(response, node, callback) {
    
        // Transfer the response for the tree panel
        var json = Ext.util.JSON.decode(response.responseText);
        
        if (Ext.type(json.teams)) {
            Ext.apply(response, {
                responseText: this.generateTeamNodes(json)
            });
        }
        else 
            if (Ext.type(json.players)) {
                Ext.apply(response, {
                    responseText: this.generatePlayerNodes(json)
                });
            }
        
        hockeystats.panel.TeamListTreeLoader.superclass.processResponse.call(this, response, node, callback);
    }
});


