/**
 * @author tlomenda
 */
Ext.namespace('hockeystats.panel');

hockeystats.panel.PlayerInfoPanel = function(config) {
    var panelConfig = config ? config : {};
    
    Ext.apply(panelConfig, {
        layout: 'accordion',
		cls: 'my-accordion',
        items: [{
            title: 'Player Profile',
            // html: 'Player Profile Info',
            collapsed: true,
            autoHeight: true
        }, {
            title: 'Player Stats & News',
            autoHeight: true,
            collapsed: true,
            // Set the items for the player stats (a tab panel
            items: [{
                xtype: 'tabpanel',
                activeItem: 0,
                items: [{
                    title: 'Stats'
                    //     html: "Stats Data"
                }, {
                    title: 'News'
                    //     html: "News Data"
                }],
				
				listeners: {
					tabchange: {fn:  function(tabpanel, tab) {
						// Tab change requires a call to doLayout() to ensure that all the components on the "tab"
						// are rendered within the tabpanel
						tabpanel.doLayout();
					}, scope: this}
				}
            }]
        }]
    });
    
    hockeystats.panel.PlayerInfoPanel.superclass.constructor.call(this, panelConfig);
}

Ext.extend(hockeystats.panel.PlayerInfoPanel, Ext.Panel, {

    updateInfo: function(playerId) {
        // Make sure it is not the root node or a team node
        if (!!playerId && playerId !== 'extTeamListRootNode' && playerId.indexOf('-') !== -1) {
            // Parse the id (we know it is in the form reportId-playerId)
            var idList = playerId.split('-');
            
            // Load the JSON Model for this UI.  We know the player id is the second element in the id list (the first is the team id)
            if (idList.length > 1) {
                this.fetchPlayer(idList[1]);
            }
        }
    },
    
    fetchPlayer: function(playerId) {
        // Perform an Ajax request to load the model, and update the UI upon success
        var successFn = function(response) {
            this.loadModel(response);
        };
        
        Ext.Ajax.request({
            url: HockeyStats.PLAYER_REST_URL + '/' + playerId,
            method: 'GET',
            success: successFn.createDelegate(this),
            failure: function(response) {
                Ext.MessageBox.alert("Loading Player Error", "The player with id '" + playerId + "'could not be loaded :-(");
            }
        });
    },
    
    loadModel: function(response) {
        // Decode the JSON and set the scouting report model for this component
        var playerModel = Ext.util.JSON.decode(response.responseText);
        
        Ext.apply(this, {
            playerInfo: playerModel
        });
        
        // Change the titles for the accordions
        this.updateTitle();
        
        // Add Data Grids to the Panels
        this.updateData();
        
        // Collapse the panels
        this.expandFirst();
    },
    
    expandFirst: function() {
        this.getPlayerProfilePanel().expand();
    },
    
    updateTitle: function() {
        if (!!this.playerInfo) {
            var playerProfile = this.playerInfo.player;
            this.getPlayerProfilePanel().setTitle('Player Profile - ' + playerProfile.firstName + ' ' + playerProfile.lastName);
            this.getPlayerStatsAndNewsPanel().setTitle('Player Stats & News - ' + playerProfile.firstName + ' ' + playerProfile.lastName);
        }
    },
    
    updateData: function() {
        // Step 6
        this.updatePlayerProfilePanel();
        this.updatePlayerStatsPanel();
		this.updatePlayerNewsPanel();
    },
    
    updatePlayerProfilePanel: function() {
        // Remove all components in the scouting report panel
        var playerProfilePanel = this.getPlayerProfilePanel();
        
        if (!!playerProfilePanel.items) {
            // Refresh the form values
            this.refreshPlayerProfilePanel();
        }
        else {
            // Add the Form
            var form = new Ext.form.FormPanel({
                hideCollapseTool: true,
                items: [{
                    xtype: 'fieldset',
                    title: 'Profile',
                    autoHeight: true,
                    collapsible: false,
                    items: [{
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Number',
                        name: 'number',
                        value: this.playerInfo.player.number,
                        width: 50
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'First Name',
                        name: 'firstName',
                        value: this.playerInfo.player.firstName,
                        width: 150
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Last Name',
                        name: 'lastName',
                        value: this.playerInfo.player.lastName,
                        width: 150
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Height (Feet)',
                        value: this.playerInfo.player.heightFeet,
                        name: 'heightFeet',
                        width: 50
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Height (Inches)',
                        name: 'heightInches',
                        value: this.playerInfo.player.heightInches,
                        width: 50
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Weight (lbs)',
                        name: 'weightInPounds',
                        value: this.playerInfo.player.weightInPounds,
                        width: 50
                    }]
                }],
                buttons: [{
                    text: 'Update',
                    formBind: true, // Used so that the button is only enabled when validation passes.
                    handler: function() {
                        // Submit the form.  On success reload the form
                        Ext.MessageBox.alert('Implement Submit', 'TODO;  Implement the submit');
                    }
                }]
            });
            
            playerProfilePanel.add(form);
        }
    },
    
    refreshPlayerProfilePanel: function() {
        var formPanel = this.getPlayerProfilePanel().items.get(0);
        var player = this.playerInfo.player;
        
        // Ensure that the fields have been rendered
        if (formPanel.form.items.get(0)) {
            formPanel.form.items.get(0).setRawValue(player.number);
            formPanel.form.items.get(1).setRawValue(player.firstName);
            formPanel.form.items.get(2).setRawValue(player.lastName);
            formPanel.form.items.get(3).setRawValue(player.heightFeet);
            formPanel.form.items.get(4).setRawValue(player.heightInches);
            formPanel.form.items.get(5).setRawValue(player.weightInPounds);
        }
    },
    
    updatePlayerStatsPanel: function() {
        var playerStatsAndNewsPanel = this.getPlayerStatsAndNewsPanel();
        var playerStatsTab = this.getPlayerStatsTab();
        
        // Have all the UI components been rendered (Watch for lazy instantiation
        if (!!playerStatsTab.items) {
            this.refreshPlayerStatsPanel();
        }
        else {
            // Add the grids
            var statsStore = new Ext.data.JsonStore({
                data: this.playerInfo,
                root: 'playerStats',
                fields: [{
                    name: 'goals'
                }, {
                    name: 'assists'
                }, {
                    name: 'plusMinus'
                }, {
                    name: 'hits'
                }, {
                    name: 'takeAways'
                }, {
                    name: 'scoringChances'
                }, {
                    name: 'playResultedInGoalFor'
                }, {
                    name: 'pims'
                }, {
                    name: 'giveAways'
                }, {
                    name: 'playResultedInGoalAgainst'
                }]
            });
            
            var statsGrid = new Ext.grid.GridPanel({
                store: statsStore,
                autoHeight: true,
                columns: [{
                    header: "Goals",
                    dataIndex: 'goals',
                    sortable: true
                }, {
                    header: "Assists",
                    dataIndex: 'assists',
                    sortable: true
                }, {
                    header: "Plus/Minus",
                    dataIndex: 'plusMinus',
                    sortable: true
                }, {
                    header: "Hits",
                    dataIndex: 'hits',
                    sortable: true
                }, {
                    header: "Take Aways",
                    dataIndex: 'takeAways',
                    sortable: true
                }, {
                    header: "Scoring Chances",
                    dataIndex: 'scoringChances',
                    sortable: true
                }, {
                    header: "Play-Goal For",
                    dataIndex: 'playResultedInGoalFor',
                    sortable: true
                }, {
                    header: "Penalty Minutes",
                    dataIndex: 'pims',
                    sortable: true
                }, {
                    header: "Give Aways",
                    dataIndex: 'giveAways',
                    sortable: true
                }, {
                    header: "Play-Goal Against",
                    dataIndex: 'playResultedInGoalAgainst',
                    sortable: true
                }],
                
                // Other options
                viewConfig: {
                    forceFit: true,
                    
                    // Used to color odd and even rows
                    getRowClass: function(record, index) {
                        if (index % 2 === 0) {
                            return 'even-row';
                        }
                        else {
                            return 'odd-row';
                        }
                        
                    }
                }
            
            });
			
            // Add grids to the appropriate tab panel
            playerStatsTab.add(statsGrid);
        }
    },
    
    refreshPlayerStatsPanel: function() {
        var playerStatsAndNewsPanel = this.getPlayerStatsAndNewsPanel();
        var playerStatsTab = this.getPlayerStatsTab();
        
		if (!this.addedStatsGridListener) {
			var handlerFn = function() {this.doLayout()};
			playerStatsTab.items.get(0).getStore().on('load', handlerFn, this);
			this.addedStatsGridListener = true;
		}
		
        playerStatsTab.items.get(0).getStore().loadData(this.playerInfo);
    },
	
	updatePlayerNewsPanel: function() {
        var playerStatsAndNewsPanel = this.getPlayerStatsAndNewsPanel();
        var playerNewsTab = this.getPlayerNewsTab();
        
        // Have all the UI components been rendered (Watch for lazy instantiation
        if (!!playerNewsTab.items) {
            this.refreshPlayerNewsPanel();
        }
        else {
            // Add the grids
            var newsStore = new Ext.data.JsonStore({
                data: this.playerInfo,
                root: 'playerNews',
                fields: [{
                    name: 'newsDate'
                }, {
                    name: 'news'
                }]
            });
			
            var newsGrid = new Ext.grid.GridPanel({
                store: newsStore,
                autoHeight: true,
                columns: [{
                    header: "Date",
                    dataIndex: 'newsDate',
                    sortable: true
                }, {
                    header: "News Item",
                    dataIndex: 'news',
                    width: 300
                }],
                
                // Other options
                viewConfig: {
                    forceFit: true,
                    
                    // Used to color odd and even rows
                    getRowClass: function(record, index) {
                        if (index % 2 === 0) {
                            return 'even-row';
                        }
                        else {
                            return 'odd-row';
                        }
                    }
                }
            
            });
            
            // Add grids to the appropriate tab panel
            playerNewsTab.add(newsGrid);
        }
    },
    
    refreshPlayerNewsPanel: function() {
        var playerStatsAndNewsPanel = this.getPlayerStatsAndNewsPanel();
        var playerNewsTab = this.getPlayerNewsTab();
		
		if (!this.addedNewsGridListener) {
			var handlerFn = function() {this.doLayout()};
			playerNewsTab.items.get(0).getStore().on('load', handlerFn, this);
			this.addedNewsGridListener = true;
		}
		
        playerNewsTab.items.get(0).getStore().loadData(this.playerInfo);
    },
    
    getPlayerProfilePanel: function() {
        return this.items.get(0);
    },
    
    getPlayerStatsAndNewsPanel: function() {
        return this.items.get(1);
    },
    
    getPlayerStatsTab: function() {
        return this.getPlayerStatsAndNewsPanel().items.get(0).items.get(0);
    },
    
    getPlayerNewsTab: function() {
        return this.getPlayerStatsAndNewsPanel().items.get(0).items.get(1);
    }
});

Ext.reg('hockeystats.panel.PlayerInfoPanel', hockeystats.panel.PlayerInfoPanel);
