/**
 * @author tlomenda
 */
Ext.namespace('hockeystats.panel');

hockeystats.panel.ScoutingReportInfoPanel = function(config) {
    var panelConfig = config ? config : {};
    
    Ext.apply(panelConfig, {
        layout: 'accordion',
		cls: 'my-accordion',
        items: [{
            title: 'Scouting Report',
            //     html: 'Player Scouting Report',
            collapsed: true,
            autoHeight: true
        }, {
            title: 'Player Scouting Notes',
            // html: 'Player Scouting Notes',
            collapsed: true,
            autoHeight: true
        }]
    });
    
    hockeystats.panel.ScoutingReportInfoPanel.superclass.constructor.call(this, panelConfig);
}

Ext.extend(hockeystats.panel.ScoutingReportInfoPanel, Ext.Panel, {
    /**
     * This function is called to update the information in this component
     */
    updateInfo: function(reportId) {
        // Make sure it is not the root node
        if (!!reportId && reportId !== 'extPlayerListRootNode') {
            // Parse the id (we know it is in the form reportId-playerId)
            var idList = reportId.split('-');
            
            // Load the JSON Model for this UI
            if (idList.length > 0) {
                this.fetchReport(idList[0]);
            }
        }
    },
    
    fetchReport: function(reportId) {
        // Perform an Ajax request to load the model, and update the UI upon success
        var successFn = function(response) {
            this.loadModel(response);
        };
        
        Ext.Ajax.request({
            url: HockeyStats.SCOUT_REPORT_REST_URL + '/' + reportId,
            method: 'GET',
            success: successFn.createDelegate(this),
            failure: function(response) {
                Ext.MessageBox.alert("Loading Report Error", "The report with id '" + reportId + "'could not be loaded :-(");
            }
        });
    },
    
    loadModel: function(response) {
        // Decode the JSON and set the scouting report model for this component
        var scoutingReportModel = Ext.util.JSON.decode(response.responseText);
        
        Ext.apply(this, {
            scoutingReportInfo: scoutingReportModel
        });
        
        // Change the titles for the accordions
        this.updateTitle();
        
        // Add Data Grids to the Panels
        this.updateData();
        
        // Expand the first panel
        this.expandFirst();
    },
    
    expandFirst: function() {
        this.getScoutingReportPanel().expand();
    },
    
    updateTitle: function() {
        if (!!this.scoutingReportInfo) {
            var reportInfo = this.scoutingReportInfo.scoutingReport;
            this.getScoutingReportPanel().setTitle('Scouting Report - ' + reportInfo.firstName + ' ' + reportInfo.lastName);
            this.getScoutingNotesPanel().setTitle('Player Scouting Notes - ' + reportInfo.firstName + ' ' + reportInfo.lastName);
        }
    },
    
    updateData: function() {
        // Step 6
        this.updateScoutingReportPanel();
        this.updateScoutingNotesPanel();
    },
    
    updateScoutingReportPanel: function() {
        // Remove all components in the scouting report panel
        var scoutingReportPanel = this.getScoutingReportPanel();
        
        if (!!scoutingReportPanel.items) {
            // Refresh the form values
            this.refreshScoutingReportPanel();
        }
        else {
            // Add the Form
            var form = new Ext.form.FormPanel({
                hideCollapseTool: true,
                items: [{
                    xtype: 'fieldset',
                    title: 'Player Ratings (1-10)',
                    autoHeight: true,
                    collapsible: true,
                    items: [{
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Skating',
                        name: 'ratingSkating',
                        value: this.scoutingReportInfo.scoutingReport.ratingSkating,
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Puck Control',
                        name: 'ratingPuckControl',
                        value: this.scoutingReportInfo.scoutingReport.ratingPuckControl,
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Physical Play',
                        name: 'ratingPhysicalPlay',
                        value: this.scoutingReportInfo.scoutingReport.ratingPhysicalPlay,
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Size',
                        value: this.scoutingReportInfo.scoutingReport.ratingSize,
                        name: 'ratingSize',
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Intensity',
                        name: 'ratingIntensity',
                        value: this.scoutingReportInfo.scoutingReport.ratingIntensity,
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Hockey Sense',
                        name: 'ratingHockeySense',
                        value: this.scoutingReportInfo.scoutingReport.ratingHockeySense,
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Offensive Play',
                        name: 'ratingOffensivePlay',
                        value: this.scoutingReportInfo.scoutingReport.ratingOffensivePlay,
                        width: 100
                    }, {
                        xtype: 'textfield',
                        allowBlank: false, // This field is required
                        fieldLabel: 'Defensive Play',
                        name: 'ratingDefensivePlay',
                        value: this.scoutingReportInfo.scoutingReport.ratingDefensivePlay,
                        width: 100
                    }]
                
                }, {
                    xtype: 'fieldset',
                    title: 'Player Notes',
                    autoHeight: true,
                    collapsible: true,
                    items: [{
                        xtype: 'textarea',
                        fieldLabel: 'Strengths',
                        name: 'strengths',
                        value: this.scoutingReportInfo.scoutingReport.strengths,
                        width: 400,
                        height: 50
                    }, {
                        xtype: 'textarea',
                        fieldLabel: 'weaknesses',
                        name: 'Weaknesses',
                        value: this.scoutingReportInfo.scoutingReport.weaknesses,
                        width: 400,
                        height: 50
                    }, {
                        xtype: 'textarea',
                        fieldLabel: 'Tendencies',
                        name: 'tendencies',
                        value: this.scoutingReportInfo.scoutingReport.tendencies,
                        width: 400,
                        height: 50
                    }, {
                        xtype: 'textarea',
                        fieldLabel: 'General',
                        name: 'generalNotes',
                        value: this.scoutingReportInfo.scoutingReport.generalNotes,
                        width: 400,
                        height: 50
                    }]
                }],
                buttons: [{
                    text: 'Update',
                    formBind: true, // Used so that the button is only enabled when validation passes.
                    handler: function() {
                        // Submit the form.  On success reload the form
                        Ext.MessageBox.alert('Implement Submit', 'TODO;  Implement the submit');
                    }
                }]
            });
            
            scoutingReportPanel.add(form);
        }
    },
    
    refreshScoutingReportPanel: function() {
        var formPanel = this.getScoutingReportPanel().items.get(0);
        var scoutingReport = this.scoutingReportInfo.scoutingReport;
        
        // Ensure that the fields have been rendered
        if (formPanel.form.items.get(0)) {
            formPanel.form.items.get(0).setRawValue(scoutingReport.ratingSkating);
            formPanel.form.items.get(1).setRawValue(scoutingReport.ratingPuckControl);
            formPanel.form.items.get(2).setRawValue(scoutingReport.ratingPhysicalPlay);
            formPanel.form.items.get(3).setRawValue(scoutingReport.ratingSize);
            formPanel.form.items.get(4).setRawValue(scoutingReport.ratingIntensity);
            formPanel.form.items.get(5).setRawValue(scoutingReport.ratingHockeySense);
            formPanel.form.items.get(6).setRawValue(scoutingReport.ratingOffensivePlay);
            formPanel.form.items.get(7).setRawValue(scoutingReport.ratingDefensivePlay);
            formPanel.form.items.get(8).setRawValue(scoutingReport.strengths);
            formPanel.form.items.get(9).setRawValue(scoutingReport.weaknesses);
            formPanel.form.items.get(10).setRawValue(scoutingReport.tendencies);
            formPanel.form.items.get(11).setRawValue(scoutingReport.generalNotes);
        }
    },
    
    updateScoutingNotesPanel: function() {
        var scoutingNotesPanel = this.getScoutingNotesPanel();
        
        if (!!scoutingNotesPanel.items) {
            this.refreshScoutingNotesPanel();
        }
        else {
        
            // Add the grid
            var store = new Ext.data.JsonStore({
                data: this.scoutingReportInfo,
                root: 'scoutingNotes',
                fields: [{
                    name: 'id'
                }, {
                    name: 'note'
                }, {
                    name: 'dateLogged'
                }]
            });
            
            var grid = new Ext.grid.GridPanel({
                store: store,
                autoHeight: true,
                columns: [{
                    header: "Date Logged",
                    dataIndex: 'dateLogged',
					width: 30,
                    sortable: true
                }, {
                    header: "Note",
                    dataIndex: 'note'
                }],
                
                // Other options
                viewConfig: {
                    forceFit: true,
                    
                    // Used to color odd and even rows
                    getRowClass: function(record, index) {
                        if (index % 2 === 0) {
                            return 'even-row';
                        }
                        else {
                            return 'odd-row';
                        }
                    }
                }
            
            });
            
            scoutingNotesPanel.add(grid);
        }
    },
    
    refreshScoutingNotesPanel: function() {
        var scoutingNotesPanel = this.getScoutingNotesPanel();
        scoutingNotesPanel.items.get(0).getStore().loadData(this.scoutingReportInfo);
    },
    
    getScoutingReportPanel: function() {
        return this.items.get(0);
    },
    
    getScoutingNotesPanel: function() {
        return this.items.get(1);
    }
    
});

Ext.reg('hockeystats.panel.ScoutingReportInfoPanel', hockeystats.panel.ScoutingReportInfoPanel);
