YAHOO.namespace("hockeystats.panel");

YAHOO.hockeystats.panel.TeamListPanel = function() {

    var teamUrl = HockeyStats.TEAM_REST_URL;
    var playerUrl = HockeyStats.PLAYER_REST_URL + '/team/';
    
    function _createTeamNodes(jsonText, node) {
        var jsonObj = YAHOO.lang.JSON.parse(jsonText);
        
        // New array for our team nodes
        teamNodes = [];
        
        if (!!jsonObj.teams) {
            var teams = jsonObj.teams;
            
            for (var i = 0; i < teams.length; i++) {
                var team = teams[i];
                
                // Add the node
				var teamNode = new YAHOO.widget.TextNode({
                    label: '<img src="../images/hockeystats/playerHelmet.gif" height="18" width="18" />' + team.name,
                    id: team.id
                }, node);
				
				teamNode.id = 'teamNode-' + team.id;
				teamNode.labelElId = 'teamNode-' + team.id;
				teamNode.labelStyle = 'icon-team';
				teamNode.setDynamicLoad(_loadData);
                teamNodes.push(teamNode);
            }
        }
    }
    
    function _createPlayerNodes(jsonText, node) {
		var jsonObj = YAHOO.lang.JSON.parse(jsonText);
        
        // New array for our team nodes
        playerNodes = [];
        
        if (!!jsonObj.players) {
            var players = jsonObj.players;
            
            for (var i = 0; i < players.length; i++) {
                var player = players[i];
                
                // Add the node
				var playerNode = new YAHOO.widget.TextNode({
                    label: '<img src="../images/hockeystats/player.gif" height="18" width="18"/>' + player.number + ' - ' + player.firstName + ' ' + player.lastName,
                    id: player.teamId + '-' + player.id
                }, node);
				
				playerNode.id = 'playerNode-' + player.teamId + '-' + player.id;
				playerNode.labelElId = 'playerNode-' + player.teamId + '-' + player.id;
				playerNode.labelStyle = 'icon-player';
                playerNodes.push(playerNode);
            }
        }
    
    }
    
    function _loadData(node, onCompleteCallback) {
    
        // Closure around the node
        var parentNode = node;
        var parentNodeId = node.id;
        
        var handleSuccess = function(response) {
        
        
            if (parentNodeId === 'teamListParentNode') {
                // Create Team Nodes
				_createTeamNodes(response.responseText, parentNode);
            }
            else {
                // Create player nodes for the Team
				_createPlayerNodes(response.responseText, parentNode);
            }
			
			// Need to notify the tree that the loadData is complete
			onCompleteCallback();
        }
        
        
        var callback = {
            success: handleSuccess,
            failure: function(o) {
                alert("There was a problem creating Team List Nodes!!");
            }
        }
        
        if (parentNodeId === 'teamListParentNode') {
            var transaction = YAHOO.util.Connect.asyncRequest("GET", teamUrl, callback);
        }
        else {
			var teamId = node.id.split("-")[1]
            var transaction = YAHOO.util.Connect.asyncRequest("GET", playerUrl + teamId, callback);
        }
        
    }
	
	function _initializeClickEventToRefreshPlayerData(tree) {
        // Register events when a node is clicked and it has a scouting report id
        tree.subscribe("clickEvent", function(event) {
        
            // Fetch the scouting report information
            var callbackStats = {
                success: GRAILSUI.playerStatsDataTable.onDataReturnInitializeTable,
				
                failure: function(o) {
                    alert("There was a problem refreshing the data!!");
                },
				scope:  GRAILSUI.playerStatsDataTable
            };
			var callbackNews = {
                success: GRAILSUI.playerNewsDataTable.onDataReturnInitializeTable,
                failure: function(o) {
                    alert("There was a problem refreshing the data!!");
                },
				scope:  GRAILSUI.playerNewsDataTable
            };
            
            if (event.node.id !== 'teamListParentNode' && event.node.id.indexOf('teamNode') === -1) {
				// I can override this to set the player profile info from the response returned by sending a request on this data source
				GRAILSUI.playerStatsDataTable.getDataSource().doBeforeParseData = function(request, fullResponse, callback) {
					YAHOO.util.Dom.get('player-number').value = fullResponse.player.number;
                    YAHOO.util.Dom.get('player-firstName').value = fullResponse.player.firstName;
                    YAHOO.util.Dom.get('player-lastName').value = fullResponse.player.lastName;
					YAHOO.util.Dom.get('player-heightFeet').value = fullResponse.player.heightFeet;
					YAHOO.util.Dom.get('player-heightInches').value = fullResponse.player.heightInches;
					YAHOO.util.Dom.get('player-weightInPounds').value = fullResponse.player.weightInPounds;
					
					return fullResponse;
				}
				
				var nodeIdParts = event.node.id.split("-");
				GRAILSUI.playerStatsDataTable.getDataSource().sendRequest("id=" + nodeIdParts[2], callbackStats);
                GRAILSUI.playerNewsDataTable.getDataSource().sendRequest("id=" + nodeIdParts[2], callbackNews);
            }
        });
    }
    
    return {
        initTree: function() {
        
            // Create the tree view object
            var tree = new YAHOO.widget.TreeView('teamListTree');
            
            // Define the root node
            var root = tree.getRoot();
            var teamListNode = new YAHOO.widget.TextNode({
                label: 'My Team List',
                labelElId: 'teamListParentNode'
            }, root, false); // note expanded 
    
	        // Add the nodes (dynamically).  NOTE:  Have to attach other proerpties it to the node explicitly.  Even labelElId which is said to be supported!! :-(
			teamListNode.id = 'teamListParentNode';
			teamListNode.labelElId = 'teamListParentNode';
            teamListNode.setDynamicLoad(_loadData);
            
            
            // Draw the tree
            tree.draw();
			
			_initializeClickEventToRefreshPlayerData(tree);
        }
    }
}();
